unit Edit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, PtblRV, RVScroll, RichView, RVEdit, RVStyle, StdCtrls, RVTable;

type
  TForm1 = class(TForm)
    RichViewEdit1: TRichViewEdit;
    RVPrint1: TRVPrint;
    Button1: TButton;
    Button2: TButton;
    RVStyle1: TRVStyle;
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
  private
    { Private declarations }
    procedure DoDrawBorder(Sender: TRVTableItemInfo; Canvas: TCanvas;
      Left, Top, Right, Bottom, Width: Integer; LightColor, Color,
      BackgroundColor: TColor; Style: TRVTableBorderStyle; Printing: Boolean;
      VisibleBorders: TRVBooleanRect; Row, Col : integer; var DoDefault: Boolean);
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

{ This procedure prints hairline (width = 1 pixel) border.
  For all cells, except for the outermost (top and right) cells, only
  the right and the bottom border sides are drawn (because other sides are
  drawn by the cell to the right/top).
  VisibleBorders are taken into account (for cells, not for the table as a whole)

  On the screen, hairline border looks exactly like normal "1 screen pixel" border.
  But when printing, it depends on the printer resolution.
  Width of default "1 screen pixel" border on paper is calculated as
  Printer_Resolution/Screen_Resolution. For example, if Screen_Resolution=96,
  6 pixels is used on 600 dpi printers, and 12 pixels on 1200 dpi printers.
  Unlike the default procedure, this event always draws 1 pixel border,
  and it may look very thin on paper }

procedure TForm1.DoDrawBorder(Sender: TRVTableItemInfo;
  Canvas: TCanvas; Left, Top, Right, Bottom, Width: Integer; LightColor,
  Color, BackgroundColor: TColor; Style: TRVTableBorderStyle;
  Printing: Boolean; VisibleBorders: TRVBooleanRect; Row, Col: integer;
  var DoDefault: Boolean);
begin
  if Width = 0 then exit;
  if not Printing then exit;

  inc(Right);
  inc(Bottom);

  Canvas.Pen.Color := Color;
  Canvas.Pen.Style := psInsideFrame;
  Canvas.Pen.Width := 1;
  Canvas.Brush.Style := bsClear;

  if Row<0 then
    Canvas.Rectangle(Left, Top, Right, Bottom)
  else begin
    Canvas.MoveTo(Left, Top);
    if Sender.Cells[Row, Col].VisibleBorders.Top and
       ((Row=0) or not Sender.Cells[Row-1, Col].VisibleBorders.Bottom) then
      Canvas.LineTo(Right, Top)
    else
      Canvas.MoveTo(Right, Top);
    if Sender.Cells[Row, Col].VisibleBorders.Right then
      Canvas.LineTo(Right, Bottom)
    else
      Canvas.MoveTo(Right, Bottom);
    if Sender.Cells[Row, Col].VisibleBorders.Bottom then
      Canvas.LineTo(Left, Bottom)
    else
      Canvas.MoveTo(Left, Bottom);
    if Sender.Cells[Row, Col].VisibleBorders.Left and
       ((Col=0) or not Sender.Cells[Row, Col-1].VisibleBorders.Right) then
      Canvas.LineTo(Left, Top)
    else
      Canvas.MoveTo(Left, Top);
  end;

  DoDefault := False;
end;

procedure TForm1.Button1Click(Sender: TObject);
var
  table: TRVTableItemInfo;
  i, j: Integer;
  pi: TParaInfo;
  fi: TFontInfo;
  NewParaStyleNo, NewFontStyleNo: integer;
  rowCnt, colCnt : integer;
begin
  table := TRVTableItemInfo.CreateEx(3, 3, RichViewEdit1.RVData);
  table.options := [rvtoEditing, rvtoRowSizing, rvtoColSizing];
  table.options := table.options + [rvtoRowSelect, rvtoColSelect,
    rvtoRTFSaveCellPixelBestWidth];
  table.options := table.options + [rvtoHideGridLines, rvtoCellBelowBorders,
    rvtoOverlappingCorners,rvtoIgnoreContentWidth, rvtoIgnoreContentHeight];

  table.CellBorderStyle := rvtbColor;
  table.CellBorderColor := clBlack;
  table.CellBorderWidth := 1;
  table.CellHSpacing := -1;
  table.CellVSpacing := -1;
  table.CellPadding := 3;
  table.BorderVSpacing := -1;
  table.BorderHSpacing := -1;
  table.BestWidth := -100;
  table.OnDrawBorder := DoDrawBorder;

  if RichViewEdit1.InsertItem('BLANK', table) then
  begin
  end;
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
  RVPrint1.AssignSource(RichViewEdit1);
  RVPrint1.FormatPages(rvdoALL);

  RVPrint1.PrintPages(1, RVPrint1.PagesCount, 'EditTest', 1, False);
end;

end.
